@@ -25,9 +25,7 @@ preserve_perms() {
 config etc/ConsoleKit/seats.d/00-primary.seat.new
 preserve_perms etc/rc.d/rc.consolekit.new
 
-( cd usr/lib ; rm -rf libck-connector.so )
-( cd usr/lib ; ln -sf libck-connector.so.0.0.0 libck-connector.so )
 ( cd usr/lib ; rm -rf libck-connector.so.0 )
 ( cd usr/lib ; ln -sf libck-connector.so.0.0.0 libck-connector.so.0 )
-( cd usr/doc/ConsoleKit-0.4.3 ; rm -rf html )
-( cd usr/doc/ConsoleKit-0.4.3 ; ln -sf /usr/share/gtk-doc/html/polkit-1 html )
+( cd usr/lib ; rm -rf libck-connector.so )
+( cd usr/lib ; ln -sf libck-connector.so.0.0.0 libck-connector.so )
